@@ -19,7 +19,7 @@ use constant CASE_TOLERANT   => File::Spec->case_tolerant;
 use constant DEBUG           => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 use constant RECURSION_LIMIT => $ENV{JSON_VALIDATOR_RECURSION_LIMIT} || 100;
 
-our $VERSION = '4.04';
+our $VERSION = '4.05';
 our @EXPORT_OK = qw(joi validate_json);
 
 our %SCHEMAS = (
@@ -186,7 +186,7 @@ sub validate {
   local $self->{schema}      = $self->_new_schema($schema);
   local $self->{seen}        = {};
   local $self->{temp_schema} = [];                            # make sure random-errors.t does not fail
-  my @errors = $self->_validate($_[1], '', $schema);
+  my @errors = sort { $a->path cmp $b->path } $self->_validate($_[1], '', $schema);
   return @errors;
 }
 
@@ -1356,7 +1356,9 @@ DEPRECATED.
   my @errors = $jv->validate($data, $schema);
 
 Validates C<$data> against a given JSON L</schema>. C<@errors> will
-contain validation error objects or be an empty list on success.
+contain validation error objects, in a predictable order (specifically,
+ASCIIbetically sorted by the error objects' C<path>) or be an empty
+list on success.
 
 See L</ERROR OBJECT> for details.
 
